@@ -1,12 +1,17 @@
 # -*- coding: utf-8 -*-
 
+try:
+    from django.conf.urls import patterns, url
+except ImportError:  # deprecated since Django 1.4
+    from django.conf.urls.defaults import patterns, url
+
 from django.contrib import admin
-from ios_notifications.models import Device, Notification, APNService, FeedbackService
-from ios_notifications.forms import APNServiceForm
-from django.conf.urls.defaults import patterns, url
 from django.template.response import TemplateResponse
 from django.shortcuts import get_object_or_404
 
+from .models import Device, Notification, APNService, FeedbackService
+from .forms import APNServiceForm
+
 
 class APNServiceAdmin(admin.ModelAdmin):
     list_display = ('name', 'hostname')
@@ -22,9 +27,10 @@ class DeviceAdmin(admin.ModelAdmin):
 
 class NotificationAdmin(admin.ModelAdmin):
     exclude = ('last_sent_at',)
-    list_display = ('message', 'badge', 'sound', 'created_at', 'last_sent_at')
+    list_display = ('message', 'badge', 'sound', 'custom_payload', 'created_at', 'last_sent_at',)
     list_filter = ('created_at', 'last_sent_at')
-    search_fields = ('message', )
+    search_fields = ('message', 'custom_payload')
+    list_display_links = ('message', 'custom_payload',)
 
     def get_urls(self):
         urls = super(NotificationAdmin, self).get_urls()
